/**
 * SPDX-FileCopyrightText: (c) 2000 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */
AUI.add('liferay-calendar-util', function (A) {
  var DateMath = A.DataType.DateMath;
  var Lang = A.Lang;
  var Workflow = Liferay.Workflow;
  var isDate = Lang.isDate;

  var toInt = function toInt(value) {
    return Lang.toInt(value, 10, 0);
  };

  var REGEX_UNFILLED_PARAMETER = /\{\s*([^|}]+?)\s*(?:\|([^}]*))?\s*\}/g;
  var STR_DASH = '-';
  var STR_SPACE = ' ';
  var Time = {
    DAY: 86400000,
    HOUR: 3600000,
    MINUTE: 60000,
    SECOND: 1000,
    WEEK: 604800000,
    // eslint-disable-next-line
    TIME_DESC: ['weeks', 'days', 'hours', 'minutes'],
    getDescription: function getDescription(milliseconds) {
      var desc = 'minutes';
      var value = 0;

      if (milliseconds > 0) {
        var timeArray = [Time.WEEK, Time.DAY, Time.HOUR, Time.MINUTE];
        timeArray.some(function (item, index) {
          value = milliseconds / item;
          desc = Time.TIME_DESC[index];
          return milliseconds % item === 0;
        });
      }

      return {
        desc: desc,
        value: value
      };
    }
  };
  Liferay.Time = Time;
  var CalendarUtil = {
    NOTIFICATION_DEFAULT_TYPE: 'email',
    createSchedulerEvent: function createSchedulerEvent(calendarBooking) {
      var endDate = new Date(calendarBooking.endTimeYear, calendarBooking.endTimeMonth, calendarBooking.endTimeDay, calendarBooking.endTimeHour, calendarBooking.endTimeMinute);
      var startDate = new Date(calendarBooking.startTimeYear, calendarBooking.startTimeMonth, calendarBooking.startTimeDay, calendarBooking.startTimeHour, calendarBooking.startTimeMinute);
      var schedulerEvent = new Liferay.SchedulerEvent({
        allDay: calendarBooking.allDay,
        calendarBookingId: calendarBooking.calendarBookingId,
        calendarId: calendarBooking.calendarId,
        calendarResourceName: calendarBooking.calendarResourceName,
        content: calendarBooking.title,
        description: calendarBooking.description,
        endDate: endDate.getTime(),
        firstReminder: calendarBooking.firstReminder,
        firstReminderType: calendarBooking.firstReminderType,
        hasChildCalendarBookings: calendarBooking.hasChildCalendarBookings,
        hasWorkflowInstanceLink: calendarBooking.hasWorkflowInstanceLink,
        instanceIndex: calendarBooking.instanceIndex,
        location: calendarBooking.location,
        parentCalendarBookingId: calendarBooking.parentCalendarBookingId,
        recurrence: calendarBooking.recurrence,
        recurringCalendarBookingId: calendarBooking.recurringCalendarBookingId,
        secondReminder: calendarBooking.secondReminder,
        secondReminderType: calendarBooking.secondReminderType,
        startDate: startDate.getTime(),
        status: calendarBooking.status
      });
      return schedulerEvent;
    },
    destroyEvent: function destroyEvent(schedulerEvent) {
      var scheduler = schedulerEvent.get('scheduler');
      scheduler.removeEvents(schedulerEvent);
      scheduler.syncEventsUI();
    },
    fillURLParameters: function fillURLParameters(url, data) {
      url = Lang.sub(url, data);
      return url.replace(REGEX_UNFILLED_PARAMETER, '');
    },
    getCalendarName: function getCalendarName(name, calendarResourceName) {
      if (name !== calendarResourceName) {
        name = [calendarResourceName, STR_DASH, name].join(STR_SPACE);
      }

      return name;
    },
    getDateFromObject: function getDateFromObject(object) {
      var day = toInt(object.day);
      var hour = toInt(object.hour);
      var minute = toInt(object.minute);
      var month = toInt(object.month);
      var year = toInt(object.year);
      return new Date(year, month, day, hour, minute);
    },
    getDatesList: function getDatesList(startDate, total) {
      var ADate = A.Date;
      var output = [];

      if (ADate.isValidDate(startDate)) {
        for (var i = 0; i < total; i++) {
          output.push(ADate.addDays(startDate, i));
        }
      }

      return output;
    },
    getLocalizationMap: function getLocalizationMap(value) {
      var map = {};
      map[themeDisplay.getLanguageId()] = value;
      return JSON.stringify(map);
    },
    setEventAttrs: function setEventAttrs(schedulerEvent, data) {
      var scheduler = schedulerEvent.get('scheduler');
      var newCalendarId = data.calendarId;
      var oldCalendarId = schedulerEvent.get('calendarId');

      if (scheduler) {
        var calendarContainer = scheduler.get('calendarContainer');
        var newCalendar = calendarContainer.getCalendar(newCalendarId);
        var oldCalendar = calendarContainer.getCalendar(oldCalendarId);

        if (oldCalendar !== newCalendar) {
          oldCalendar.remove(schedulerEvent);
        }

        if (newCalendar) {
          newCalendar.add(schedulerEvent);
        }

        schedulerEvent.setAttrs({
          calendarBookingId: data.calendarBookingId,
          calendarId: newCalendarId,
          calendarResourceId: data.calendarResourceId,
          parentCalendarBookingId: data.parentCalendarBookingId,
          recurrence: data.recurrence,
          recurringCalendarBookingId: data.recurringCalendarBookingId,
          status: data.status
        }, {
          silent: true
        });
        scheduler.syncEventsUI();
      }
    },
    toLocalTime: function toLocalTime(utc) {
      if (!isDate(utc)) {
        utc = new Date(utc);
      }

      return DateMath.add(utc, DateMath.MINUTES, utc.getTimezoneOffset());
    },
    toUTC: function toUTC(date) {
      if (!isDate(date)) {
        date = new Date(date);
      }

      return DateMath.subtract(date, DateMath.MINUTES, date.getTimezoneOffset());
    },
    updateSchedulerEvents: function updateSchedulerEvents(schedulerEvents, calendarBooking) {
      A.each(schedulerEvents, function (schedulerEvent) {
        if (schedulerEvent.isRecurring()) {
          var scheduler = schedulerEvent.get('scheduler');
          scheduler.load();
        }

        schedulerEvent.set('status', calendarBooking.status);
      });
    }
  };
  Liferay.CalendarUtil = CalendarUtil;
  var CalendarWorkflow = {
    STATUS_MAYBE: 9
  };
  A.mix(CalendarWorkflow, Workflow);
  Liferay.CalendarWorkflow = CalendarWorkflow;
}, '', {
  requires: ['aui-datatype', 'aui-scheduler', 'aui-toolbar', 'autocomplete', 'autocomplete-highlighters']
});
//# sourceMappingURL=calendar_util.js.map